<?php
/*
Plugin Name: Author Photos
plugin URI: https://draftpress.com/products/author-photo/
Description: Add an avatar to your user profile and display avatar on site.
version: 1.1.0
Author: 99 Robots
Author URI: https://draftpress.com
License: GPL2
*/

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

/* Item Name */

if (!defined('NNROBOTS_AUTHOR_PHOTO_ITEM_NAME'))
    define('NNROBOTS_AUTHOR_PHOTO_ITEM_NAME', 'Author Photos');

/* Store URL */

if (!defined('NNROBOTS_AUTHOR_PHOTO_STORE_URL'))
    define('NNROBOTS_AUTHOR_PHOTO_STORE_URL', 'https://draftpress.com');

/* Minimum PHP version */

if (!defined('NNROBOTS_AUTHOR_PHOTO_MIN_PHP_VERSION'))
    define('NNROBOTS_AUTHOR_PHOTO_MIN_PHP_VERSION', '5.4.0');

/* Plugin Name */

if (!defined('NNROBOTS_AUTHOR_PHOTO_PLUGIN_NAME'))
    define('NNROBOTS_AUTHOR_PHOTO_PLUGIN_NAME', trim(dirname(plugin_basename(__FILE__)), '/'));

/* Plugin directory */

if (!defined('NNROBOTS_AUTHOR_PHOTO_PLUGIN_DIR'))
    define('NNROBOTS_AUTHOR_PHOTO_PLUGIN_DIR', plugin_dir_path(__FILE__) );

/* Plugin url */

if (!defined('NNROBOTS_AUTHOR_PHOTO_PLUGIN_URL'))
    define('NNROBOTS_AUTHOR_PHOTO_PLUGIN_URL', plugins_url() . '/' . NNROBOTS_AUTHOR_PHOTO_PLUGIN_NAME);

/* Plugin verison */

if (!defined('NNROBOTS_AUTHOR_PHOTO_VERSION_NUM'))
    define('NNROBOTS_AUTHOR_PHOTO_VERSION_NUM', '1.1.0');

// Activatation / Deactivation

register_activation_hook( __FILE__, 			array('NNRobots_Author_Photo', 'register_activation'));

// Hooks / Filter

add_action('admin_menu', 						array('NNRobots_Author_Photo', 'menu'));
add_action('admin_enqueue_scripts', 			array('NNRobots_Author_Photo', 'user_admin_scripts_include'));
add_action('show_user_profile', 				array('NNRobots_Author_Photo', 'add_field'));
add_action('edit_user_profile', 				array('NNRobots_Author_Photo', 'add_field'));
add_action('personal_options_update', 			array('NNRobots_Author_Photo', 'save_attachment_id'));
add_action('edit_user_profile_update', 			array('NNRobots_Author_Photo', 'save_attachment_id'));
add_action('init', 								array('NNRobots_Author_Photo', 'load_textdoamin'));
add_action('admin_notices', 					array('NNRobots_Author_Photo', 'admin_notices'));

$plugin = plugin_basename(__FILE__);
add_filter("plugin_action_links_$plugin", 		array('NNRobots_Author_Photo', 'settings_link'));

// Shortcode

add_shortcode('nnr_author_photo', 				array('NNRobots_Author_Photo', 'nnr_author_photo_shortcode'));

// Software Licensing Updates

add_action('wp_ajax_nnr_ap_license_action', 	array('NNRobots_Author_Photo', 'license_action'));

if ( !class_exists('EDD_SL_Plugin_Updater') ) {
	include_once( dirname( __FILE__ ) . '/admin/include/edd-software-licensing-updates/EDD_SL_Plugin_Updater.php' );
}

$edd_updater = new EDD_SL_Plugin_Updater( NNROBOTS_AUTHOR_PHOTO_STORE_URL , __FILE__, array(
		'version' 	=> NNROBOTS_AUTHOR_PHOTO_VERSION_NUM,
		'license' 	=> NNRobots_Author_Photo::get_license_key(),
		'item_name' => NNROBOTS_AUTHOR_PHOTO_ITEM_NAME,
		'author' 	=> '99 Robots',
	)
);

/**
 * NNRobots_Author_Photo class.
 */
class NNRobots_Author_Photo {

	/**
	 * prefix
	 *
	 * (default value: 'nnrobotos_author_photo_')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $prefix = 'nnrobotos_author_photo_';

	/**
	 * prefix_dash
	 *
	 * (default value: 'nnr-ap-')
	 *
	 * @var string
	 * @access public
	 * @static
	 */
	static $prefix_dash = 'nnr-ap-';

	/**
	 * settings_page
	 *
	 * (default value: 'nnrobots-author-photo-admin-settings')
	 *
	 * @var string
	 * @access private
	 * @static
	 */
	static $settings_page = 'nnrobots-author-photo-admin-settings';

	/**
	 * text_domain
	 *
	 * (default value: '99robots-avatar')
	 *
	 * @var string
	 * @access private
	 * @static
	 */
	static $text_domain = '99robots-avatar';

	/**
	 * default
	 *
	 * @var mixed
	 * @access private
	 * @static
	 */
	static $default = array(
		'size'				=> '50',
		'default'			=> '',
		'override_avatar'	=> true,
	);

	/**
	 * Performs tasks needed upon activation
	 *
	 * @since 1.0.0
	 */
	static function register_activation() {

		/* Check if multisite, if so then save as site option */

		if (is_multisite()) {
			add_site_option(self::$prefix . 'version', NNROBOTS_AUTHOR_PHOTO_VERSION_NUM);
		} else {
			add_option(self::$prefix . 'version', NNROBOTS_AUTHOR_PHOTO_VERSION_NUM);
		}
	}

	/**
	 * Hooks to 'plugin_action_links_' filter
	 *
	 * @since 1.0.0
	 */
	static function settings_link($links) {
		$settings_link = '<a href="options-general.php?page=' . self::$settings_page . '">Settings</a>';
		array_unshift($links, $settings_link);
		return $links;
	}

	/**
	 * Load the text domain
	 *
	 * @since 1.0.0
	 */
	static function load_textdoamin() {
		load_plugin_textdomain(self::$text_domain, false, basename( dirname( __FILE__ ) ) . '/languages' );
	}

	/**
	 * Display admin notices
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function admin_notices() {

		$show_avatars = get_option('show_avatars');

		if ( isset($show_avatars) && !$show_avatars ) {
			echo '<div class="error">
		        <p><strong>' . __( 'Author Photos:', self::$text_domain ) . '</strong> ' . __( 'All Avatars are disabled.  Please <a href="' . get_admin_url() . 'options-discussion.php">enable</a> Avatars on your site for Author Photos to properly work.', self::$text_domain ) . '</p>
		    </div>';
		}
	}

	/**
	 * Perform all the actions with a license
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function license_action() {

		if ( !isset($_POST['license_key']) ) {
			echo '';
			die();
		}

		// data to send in our API request

		$api_params = array(
			'edd_action'	=> $_POST['license_action'],
			'license' 		=> $_POST['license_key'],
			'item_name' 	=> urlencode( NNROBOTS_AUTHOR_PHOTO_ITEM_NAME ), // the name of our product in EDD
			'url'       	=> is_multisite() ? network_home_url() : home_url()
		);

		// Call the custom API.

		$response = wp_remote_post( NNROBOTS_AUTHOR_PHOTO_STORE_URL, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params ) );

		// make sure the response came back okay

		if ( is_wp_error( $response ) ) {
			echo $response;
			die();
		}

		$license_data = json_decode( wp_remote_retrieve_body( $response ) );

		if ( $_POST['license_action'] == 'activate_license' ) {
			self::update_license_key($_POST['license_key']);
		} else if ( $_POST['license_action'] == 'deactivate_license' && $license_data->license == 'deactivated') {
			self::update_license_key('');
		}

		// decode the license data

		echo $license_data->license;

		die();

	}

	/**
	 * Check if license key is active
	 *
	 * @access public
	 * @static
	 * @param mixed $license_key
	 * @return void
	 */
	static function is_license_active( $license_key ) {

		if ( !isset( $license_key ) ) {
			return false;
		}

		// data to send in our API request

		$api_params = array(
			'edd_action'	=> 'check_license',
			'license' 		=> $license_key,
			'item_name' 	=> urlencode( NNROBOTS_AUTHOR_PHOTO_ITEM_NAME ), // the name of our product in EDD
			'url'       	=> is_multisite() ? network_home_url() : home_url()
		);

		// Call the custom API.

		$response = wp_remote_post( NNROBOTS_AUTHOR_PHOTO_STORE_URL, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params ) );

		// make sure the response came back okay

		if ( is_wp_error( $response ) ) {
			return false;
		}

		$license_data = json_decode( wp_remote_retrieve_body( $response ) );

		// decode the license data

		if ( isset($license_data->license) && $license_data->license == 'valid' ) {
			return true;
		} else {
			return false;
		}

	}

	/**
	 * Get the license key
	 *
	 * @access public
	 * @static
	 * @return void
	 */
	static function get_license_key() {

		// Get the license key from based on WordPress install

		if ( function_exists('is_multisite') && is_multisite() ) {
			$license_key = get_site_option(self::$prefix . 'license_key');
		} else {
			$license_key = get_option(self::$prefix . 'license_key');
		}

		// Check if license key is set

		if ( $license_key === false ) {
			$license_key = '';
		}

		return $license_key;
	}

	/**
	 * Update the license key
	 *
	 * @access public
	 * @static
	 * @param mixed $license_key
	 * @return void
	 */
	static function update_license_key($license_key) {

		if ( isset( $license_key ) ) {

			// Get the license key from based on WordPress install

			if ( function_exists('is_multisite') && is_multisite() ) {

				update_site_option(self::$prefix . 'license_key', $license_key);

			} else {

				update_option(self::$prefix . 'license_key', $license_key);

			}
		}
	}

	/**
	 * Hook for the admin menu
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function menu() {

		// Settings page

		$settings_page_load = add_submenu_page(
	 		'options-general.php',
	 		__("Author Photos", self::$text_domain),
	 		__("Author Photos", self::$text_domain),
	 		'manage_options',
	 		self::$settings_page,
	 		array('NNRobots_Author_Photo','settings'));

	 	add_action("admin_print_scripts-$settings_page_load", array('NNRobots_Author_Photo', 'admin_include_scripts'));
	}

	/**
	 * include_scripts function.
	 *
	 * Include css on admin
	 * @access public
	 * @static
	 * @return void
	 */
	static function admin_include_scripts() {

		// Styles

		wp_enqueue_style(self::$prefix . 'settings_css', 		NNROBOTS_AUTHOR_PHOTO_PLUGIN_URL . '/admin/css/settings.css');
		wp_enqueue_style(self::$prefix . 'bootstrap_css', 		NNROBOTS_AUTHOR_PHOTO_PLUGIN_URL . '/admin/css/nnr-bootstrap.min.css');
		wp_enqueue_style(self::$prefix . 'fontawesome_css',		NNROBOTS_AUTHOR_PHOTO_PLUGIN_URL . '/admin/include/fontawesome/css/font-awesome.min.css');

		// Scripts

		wp_enqueue_media();
		wp_enqueue_script(self::$prefix . 'bootstrap_js', 		NNROBOTS_AUTHOR_PHOTO_PLUGIN_URL . '/admin/js/bootstrap.min.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'avatar_upload_js', 	NNROBOTS_AUTHOR_PHOTO_PLUGIN_URL . '/admin/js/author-photo-upload.js', array('jquery'));
		wp_enqueue_script(self::$prefix . 'settings_js', 		NNROBOTS_AUTHOR_PHOTO_PLUGIN_URL . '/admin/js/settings.js', array('jquery'));
		wp_localize_script(self::$prefix . 'settings_js', 		'nnr_ap_data', array(
			'prefix_dash'			=> self::$prefix_dash,
			'activate_text'			=> __('Activate', self::$text_domain),
			'deactivate_text'		=> __('Deactivate', self::$text_domain),
			'no_license_key'		=> __('Please add or activate your License Key to get automatic updates.  Without a valid license key you will not receive regular updates. You can find your license key', self::$text_domain) . ' <a href="https://99robots.com/dashboard" target="_blank">here</a>',
			'expired'				=> __('EXPIRED: This license key has expired.  Please renew your license key', self::$text_domain) . ' <a href="https://99robots.com/dashboard" target="_blank">here</a>',
			'activation_error'		=> __('INVALID LICENSE KEY: The license key is not valid please try again. You can find your license key', self::$text_domain) . ' <a href="https://99robots.com/dashboard" target="_blank">here</a>.',
			'activation_valid'		=> __('SUCCESS: Your license key is valid.', self::$text_domain),
			'deactivation_valid'	=> __('SUCCESS: This site has been deactivated.', self::$text_domain),
			'deactivation_error'	=> __('DEACTIVATION FAILED: This site could not be deactivated.', self::$text_domain),
		));
	}

	/**
	 * Display Options page
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function settings() {

		global $wp_version;

		$license_key = self::get_license_key();

		$settings = get_option(self::$prefix . 'settings');

		// Default values

		if ($settings === false) {
			$settings = self::$default;
		}

		// Save Option

		if (isset($_POST['submit']) && check_admin_referer(self::$prefix . 'admin_settings_nonce')) {

			$settings = array(
				'size'				=> sanitize_text_field($_POST[self::$prefix_dash . 'size']),
				'default' 			=> isset($_POST[self::$prefix_dash . 'default-avatar']) ?
									   sanitize_text_field($_POST[self::$prefix_dash . 'default-avatar']) : null,
				'override_avatar'	=> isset($_POST[self::$prefix_dash . 'override-avatar']) && $_POST[self::$prefix_dash . 'override-avatar'] ? true : false,
			);

			// Update option

			update_option(self::$prefix . 'settings', $settings);
		}

		require_once('admin/views/settings.php');
	}

	/**
	 * Include scripts for admin page
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function user_admin_scripts_include() {

		if ((isset($_GET['page']) && $_GET['page'] == self::$settings_page) ||
			(basename($_SERVER['PHP_SELF']) == 'user-edit.php' || basename($_SERVER['PHP_SELF']) == 'profile.php')) {

			// Script

			wp_enqueue_script(self::$prefix . 'js', plugins_url('admin/js/author-photo-upload.js', __FILE__) );

		    $nnr_ap_data = array(
			    'prefix_dash'		=> self::$prefix_dash,
		    	'page'         		=> (isset($_GET['page']) && $_GET['page']) ? $_GET['page'] : '',
		        'text'         		=> __('99 Robots Avatar',self::$text_domain),
		        'button'       		=> __('Use as 99 Robots Avatar',self::$text_domain),
		        'button_default'	=> __('Use as Default 99 Robots Avatar',self::$text_domain),
		        'settings_page'		=> self::$settings_page
		    );

		    // Pass the array to the enqueued JS
		    wp_localize_script(self::$prefix . 'js', 'nnr_ap_data', $nnr_ap_data );
		}
	}

	/**
	 * Hook for adding field to user profile page.
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function add_field($user) {

		if ( current_user_can('upload_files') ) {
			wp_enqueue_media();

			if (get_user_meta(get_current_user_id(), self::$prefix . 'attachment_id', true) === false) {
				add_user_meta(get_current_user_id(), self::$prefix . 'attachment_id', '0');
			}

			require_once('admin/views/user-settings.php');
		}

	}

	/**
	 * Hook for saving attachment id to user avatar
	 *
	 * @since 1.0.0
	 *
	 * @param 	N/A
	 * @return 	N/A
	 */
	static function save_attachment_id($user_id) {
		update_user_meta($user_id, self::$prefix . 'attachment_id', sanitize_text_field($_POST[self::$prefix_dash . 'default-avatar']));
	}

	/**
	 * Create shortcode [nnr_author_photo ...]
	 *
	 * @since 1.0.0
	 *
	 * @param 	array id, size, type
	 * @return 	html code
	 */
	static function nnr_author_photo_shortcode($atts) {

		// Do not display if this is not a single post

		if (!is_singular()) {
			return null;
		}

		// Parse all the shortcode attributes

		$args = shortcode_atts( array(
			'user_id'		=> null,
			'user_email'	=> null,
			'size' 			=> 'thumbnail',
			'shape' 		=> 'rounded-square',
			'name'			=> 'false',
			'bio'			=> 'false',
			'align'			=> 'left',
			'text_wrap'		=> 'false',
			'css_class'		=> '',
		), $atts );

		// Return an avatar

		return nnr_author_photo( $args );
	}
}

/** ==================================================================================
 * Only show avatar if user have override avatar set to true
 ================================================================================== */

$nnr_ap_settings = get_option(NNRobots_Author_Photo::$prefix . 'settings');

// Default values

if ($nnr_ap_settings === false) {
	$nnr_ap_settings = NNRobots_Author_Photo::$default;
}

if ( !function_exists('get_avatar') && isset($nnr_ap_settings['override_avatar']) && $nnr_ap_settings['override_avatar'] ) :

/**
 * Retrieve the avatar `<img>` tag for a user, email address, MD5 hash, comment, or post.
 *
 * @since 2.5.0
 * @since 4.2.0 Optional `$args` parameter added.
 *
 * @param mixed $id_or_email The Gravatar to retrieve. Accepts a user_id, gravatar md5 hash,
 *                           user email, WP_User object, WP_Post object, or comment object.
 * @param int    $size       Optional. Height and width of the avatar image file in pixels. Default 96.
 * @param string $default    Optional. URL for the default image or a default type. Accepts '404'
 *                           (return a 404 instead of a default image), 'retro' (8bit), 'monsterid'
 *                           (monster), 'wavatar' (cartoon face), 'indenticon' (the "quilt"),
 *                           'mystery', 'mm', or 'mysterman' (The Oyster Man), 'blank' (transparent GIF),
 *                           or 'gravatar_default' (the Gravatar logo). Default is the value of the
 *                           'avatar_default' option, with a fallback of 'mystery'.
 * @param string $alt        Optional. Alternative text to use in &lt;img&gt; tag. Default empty.
 * @param array  $args       {
 *     Optional. Extra arguments to retrieve the avatar.
 *
 *     @type int          $height        Display height of the avatar in pixels. Defaults to $size.
 *     @type int          $width         Display width of the avatar in pixels. Defaults to $size.
 *     @type bool         $force_default Whether to always show the default image, never the Gravatar. Default false.
 *     @type string       $rating        What rating to display avatars up to. Accepts 'G', 'PG', 'R', 'X', and are
 *                                       judged in that order. Default is the value of the 'avatar_rating' option.
 *     @type string       $scheme        URL scheme to use. See set_url_scheme() for accepted values.
 *                                       Default null.
 *     @type array|string $class         Array or string of additional classes to add to the &lt;img&gt; element.
 *                                       Default null.
 *     @type bool         $force_display Whether to always show the avatar - ignores the show_avatars option.
 *                                       Default false.
 *     @type string       $extra_attr    HTML attributes to insert in the IMG element. Is not sanitized. Default empty.
 * }
 * @return false|string `<img>` tag for the user's avatar. False on failure.
 */
function get_avatar( $id_or_email, $size = 96, $default = '', $alt = '', $args = null ) {
	$defaults = array(
		// get_avatar_data() args.
		'size'          => 96,
		'height'        => null,
		'width'         => null,
		'default'       => get_option( 'avatar_default', 'mystery' ),
		'force_default' => false,
		'rating'        => get_option( 'avatar_rating' ),
		'scheme'        => null,
		'alt'           => '',
		'class'         => null,
		'force_display' => false,
		'extra_attr'    => '',
	);

	if ( empty( $args ) ) {
		$args = array();
	}

	$args['size']    = (int) $size;
	$args['default'] = $default;
	$args['alt']     = $alt;

	$args = wp_parse_args( $args, $defaults );

	if ( empty( $args['height'] ) ) {
		$args['height'] = $args['size'];
	}
	if ( empty( $args['width'] ) ) {
		$args['width'] = $args['size'];
	}

	/**
	 * Filter whether to retrieve the avatar URL early.
	 *
	 * Passing a non-null value will effectively short-circuit get_avatar(), passing
	 * the value through the {@see 'pre_get_avatar'} filter and returning early.
	 *
	 * @since 4.2.0
	 *
	 * @param string            $avatar      HTML for the user's avatar. Default null.
	 * @param int|object|string $id_or_email A user ID, email address, or comment object.
	 * @param array             $args        Arguments passed to get_avatar_url(), after processing.
	 */
	$avatar = apply_filters( 'pre_get_avatar', null, $id_or_email, $args );

	if ( ! is_null( $avatar ) ) {
		/** This filter is documented in wp-includes/pluggable.php */
		return apply_filters( 'get_avatar', $avatar, $id_or_email, $args['size'], $args['default'], $args['alt'], $args );
	}

	if ( ! $args['force_display'] && ! get_option( 'show_avatars' ) ) {
		return false;
	}

	$args = get_avatar_data( $id_or_email, $args );

	/** ==================================================================================
	 * Custom Additions
	 ================================================================================== */

	// If User ID is null then set it to the current author

	$user_id = null;

	if ( is_string($id_or_email) && !is_object($id_or_email) && (int) $id_or_email == 0 ) {
		$user = get_user_by('email', $id_or_email);
		$user_id = $user->ID;
	} else {
		$user_id = (int) $id_or_email;
	}

	$user_avatar = wp_get_attachment_url(get_user_meta($user_id, NNRobots_Author_Photo::$prefix . 'attachment_id', true));
	$avatar_settings = get_option(NNRobots_Author_Photo::$prefix . 'settings');

	$url = false;

	// Get 99 Robots Avatar

	if ( $user_avatar !== false && $user_avatar != '0' ) {

		$image = wp_get_attachment_image_src(get_user_meta($user_id, NNRobots_Author_Photo::$prefix . 'attachment_id', true), array($args['size'],$args['size']));

		if ( isset($image) && is_array($image) ) {
			$url = $image[0];
			$url2x = $image[0];
		}
	}

	// Get Default Avatar

	else if ( $avatar_settings !== false ) {

		$image = wp_get_attachment_image_src($avatar_settings['default'], array($args['size'],$args['size']));

		if ( isset($image) && is_array($image) && $image[0] != '' ) {
			$url = $image[0];
			$url2x = $image[0];
		}
	}

	// Get Gravatar

	if ( !$url ) {

		$url2x = get_avatar_url( $id_or_email, array_merge( $args, array( 'size' => $args['size'] * 2 ) ) );
		$url = $args['url'];
	}

	/** ==================================================================================
	 * Custom Additions
	 ================================================================================== */

	if ( ! $url || is_wp_error( $url ) ) {
        return false;
	}

	$class = array( 'avatar', 'avatar-' . (int) $args['size'], 'photo' );

	if ( ! $args['found_avatar'] || $args['force_default'] ) {
        $class[] = 'avatar-default';
	}

	if ( $args['class'] ) {
		if ( is_array( $args['class'] ) ) {
			$class = array_merge( $class, $args['class'] );
		} else {
			$class[] = $args['class'];
		}
	}

	$avatar = sprintf(
		"<img alt='%s' src='%s' srcset='%s' class='%s' height='%d' width='%d' %s/>",
		esc_attr( $args['alt'] ),
		esc_url( $url ),
		esc_attr( "$url2x 2x" ),
		esc_attr( join( ' ', $class ) ),
		(int) $args['height'],
		(int) $args['width'],
		$args['extra_attr']
	);

	/**
	 * Filter the avatar to retrieve.
	 *
	 * @since 2.5.0
	 * @since 4.2.0 The `$args` parameter was added.
	 *
	 * @param string            $avatar      &lt;img&gt; tag for the user's avatar.
	 * @param int|object|string $id_or_email A user ID, email address, or comment object.
	 * @param int               $size        Square avatar width and height in pixels to retrieve.
	 * @param string            $alt         Alternative text to use in the avatar image tag.
	 *                                       Default empty.
	 * @param array             $args        Arguments passed to get_avatar_data(), after processing.
	 */
	return apply_filters( 'get_avatar', $avatar, $id_or_email, $args['size'], $args['default'], $args['alt'], $args );
}
endif;

/**
 * Override the get_avatar function
 *
 * @access public
 * @param mixed $avatar
 * @param mixed $id_or_email
 * @param mixed $size
 * @param mixed $default
 * @param mixed $alt
 * @return void
 */
function nnr_get_avatar( $avatar, $id_or_email, $size, $default, $alt ) {

	$user_id = null;
	$user_email = null;

	if ( is_numeric($id_or_email) ) {
		$user_id = (int) $id_or_email;
	} else if ( is_string($id_or_email) ) {
		$user_email = $id_or_email;
	}

	if ( !isset($user_id) ) {
		$user = get_user_by('email', $user_email);

		if ( isset($user->ID) ) {
			$user_id = $user->ID;
		} else {
			return $avatar;
		}
	}

	// Get class

	$classes = '';

	$s = explode("class='",$avatar);
	$t = explode("' height",$s[1]);
	$classes = $t[0];

	// Parse all the shortcode attributes

	$args = array(
		'user_id'		=> $user_id,
		'user_email'	=> $user_email,
		'size' 			=> $size,
		'shape' 		=> 'rounded-square',
		'name'			=> 'false',
		'bio'			=> 'false',
		'align'			=> 'left',
		'text_wrap'		=> 'false',
		'css_class'		=> $classes,
	);

	// Return an avatar

	return nnr_author_photo( $args );
}

/** ==================================================================================
 * Developer function to display an Author Photo
 ================================================================================== */

/**
 * Display the author photo
 *
 * @access public
 * @param array $args (default: array())
 * @return void
 */
function nnr_author_photo( $atts = array() ) {

	$args = array_merge(array(
		'user_id'		=> null,
		'user_email'	=> null,
		'size' 			=> 'thumbnail',
		'shape' 		=> 'rounded-square',
		'name'			=> 'false',
		'bio'			=> 'false',
		'align'			=> 'left',
		'text_wrap'		=> 'false',
		'css_class'		=> '',
	), $atts);

	extract( $args );

	global $post;

	// If User ID is null then set it to the current author

	$user_id = preg_replace('/\s+/', '', $user_id);
	$og_user_id = $user_id;

	if ( !isset($user_id) || empty($user_id) || $user_id == '') {
		$user_id = isset($post->post_author) ? $post->post_author : null;

		if ( !isset($user_id) || empty($user_id) ) {
			return '';
		}
	}

	// If User email is null then set it to the current author

	$user_email = preg_replace('/\s+/', '', $user_email);

	if ( isset($user_email) && !empty($user_email) && $user_email != '' && $og_user_id == '' ) {
		$user = get_user_by('email', $user_email);
		$user_id = $user->ID;
	} else {
		$user = get_userdata($user_id);

		if ( isset($user->data->user_email) ) {
			$user_email = $user->data->user_email;
		}
	}

	// Sizes

	$theme_check = false;
	$size_class = $size;

	if ($size == 'thumbnail') {
		$size = 50;
	} else if ($size == 'small') {
		$size = 100;
	} else if ($size == 'medium') {
		$size = 150;
	} else if ($size == 'large') {
		$size = 300;
	} else if ($size == 'full') {
		$size = 1000;
	} else if ( is_numeric($size) ) {
		$size = $size;
	} else {
		$size = 50;
	}

	// Name

	if ( $name == 'true' ) {
		$name = true;
	} else {
		$name = false;
	}

	// Bio

	if ( $bio == 'true' ) {
		$bio = true;
	} else {
		$bio = false;
	}

	// Text Wrap

	$text_wrap_class = '';

	if ( $text_wrap == 'true' ) {
		$text_wrap_class = NNRobots_Author_Photo::$prefix_dash . 'text-wrap';
	}

	$avatar_settings = get_option(NNRobots_Author_Photo::$prefix . 'settings');
	$user_avatar = wp_get_attachment_url(get_user_meta($user_id, NNRobots_Author_Photo::$prefix . 'attachment_id',true));

	$code = '';

	if ( !$theme_check ) {
		$code .= '<div class="' . NNRobots_Author_Photo::$prefix_dash . 'container ' .
			NNRobots_Author_Photo::$prefix_dash . 'size-' . $size_class . ' ' .
			NNRobots_Author_Photo::$prefix_dash . 'shape-' . $shape . ' ' .
			NNRobots_Author_Photo::$prefix_dash . 'align-' . $align . ' ' .
			$text_wrap_class . '">';
	}

	$code .= get_avatar($user_id, $size);
	$user_info = get_userdata($user_id);

	// Name

	if ( $name ) {
		$code .= '<p class="' . NNRobots_Author_Photo::$prefix_dash . 'display-name">' . $user_info->display_name . '</p>';
	}

	// Bio

	if ( $bio ) {
		$code .= '<p class="' . NNRobots_Author_Photo::$prefix_dash . 'description">' .  $user_info->user_description . '</p>';
	}

	$code .= '</div>';

	wp_enqueue_style(NNRobots_Author_Photo::$prefix . 'css', NNROBOTS_AUTHOR_PHOTO_PLUGIN_URL . '/core/css/author-photo.css');

	return $code;
}

/**
 * Dont display default author avatars from wordpress
 *
 * @access public
 * @param array $args (default: array())
 * @return void
 */

add_filter('avatar_defaults', 'nnr_ap_avatar_default', 10, 1);

function nnr_ap_avatar_default( $avatar_defaults ) {
	return array();
}
